#include "StdAfx.h"
#include "ResourceViewerAction.h"
#include "Application.h"
#include "SimpleTextShape.h"
#include "SimpleImageShape.h"

REGISTER_SCRIPTLETCONTAINER_CREATOR(_T("ResourceImageListOnCreate"), ResourceImageListOnCreate);
void ResourceImageListOnCreate::OnPropertyChanged(CPropertyChangeEvent* propertyEvent)
{
	if (propertyEvent->IsProperty(ComponentProperty::OnCreate))
	{
		CListBox* listbox = dynamic_cast<CListBox*>(propertyEvent->m_pSource->FindName(_T("preview_image_list")));
		if (listbox != NULL)
		{
			CNBinaryResourceLoader* binary_loader = Application::get_instance()->GetBinaryLoader();
			CAtlMap< CString, CString > lstBinary;
			binary_loader->GetBinaryList(lstBinary);
			
			POSITION pos = lstBinary.GetStartPosition();
			while (pos)
			{
				CAtlMap< CString, CString >::CPair* pair = lstBinary.GetNext(pos);
				Item* pItem = new Item();
				listbox->AddItem(pItem);
				
				ItemPanel* itempanel = pItem->GetItemPanel();
				if (itempanel)
				{
					CSimpleTextShape* name_text = dynamic_cast<CSimpleTextShape*>(itempanel->FindName(_T("name")));
					if (name_text != NULL)
					{
						name_text->SetText(pair->m_key);
					}
					CSimpleImageShape* resource_image = dynamic_cast<CSimpleImageShape*>(itempanel->FindName(_T("resource_image")));
					if (resource_image != NULL)
					{
						IImage* image = binary_loader->GetImage(pair->m_key);
						if (image != NULL)
						{
							resource_image->SetImage(image);
						}
					}
				}
			}
			listbox->RecalcLayout();
		}
	}
}

REGISTER_SCRIPTLETCONTAINER_CREATOR(_T("ResourceStringListOnCreate"), ResourceStringListOnCreate);
void ResourceStringListOnCreate::OnPropertyChanged(CPropertyChangeEvent* propertyEvent)
{
	if (propertyEvent->IsProperty(ComponentProperty::OnCreate))
	{
		CListBox* listbox = dynamic_cast<CListBox*>(propertyEvent->m_pSource->FindName(_T("preview_string_list")));
		if (listbox != NULL)
		{
			CNStringResourceLoader* string_loader = Application::get_instance()->GetStringLoader();
			CAtlMap< CString, CString, CStringElementTraits<CString>, CStringElementTraits<CString> > lstString;
			string_loader->GetStringList(lstString);

			POSITION pos = lstString.GetStartPosition();
			while (pos)
			{
				CAtlMap< CString, CString, CStringElementTraits<CString>, CStringElementTraits<CString> >::CPair* pair = lstString.GetNext(pos);
				Item* pItem = new Item();
				listbox->AddItem(pItem);

				ItemPanel* itempanel = pItem->GetItemPanel();
				if (itempanel)
				{
					CSimpleTextShape* name_text = dynamic_cast<CSimpleTextShape*>(itempanel->FindName(_T("name")));
					if (name_text != NULL)
					{
						name_text->SetText(pair->m_key);
					}
					CSimpleTextShape* value_text = dynamic_cast<CSimpleTextShape*>(itempanel->FindName(_T("value")));
					if (value_text != NULL)
					{
						value_text->SetText(pair->m_value);
					}
				}
				
			}
			listbox->RecalcLayout();
		}
	}
}